@@ -24,7 +24,7 @@ from ..base.context import context
 from ..common.compat import isiterable
 from ..common.io import dashlist
 from ..common.iterators import groupby_to_dict as groupby
-from ..common.path import expand, is_package_file, strip_pkg_extension, url_to_path
+from ..common.path import expand, strip_pkg_extension, url_to_path
 from ..common.url import is_url, path_to_url, unquote
 from ..exceptions import InvalidMatchSpec, InvalidSpec
 from .channel import Channel
@@ -342,6 +342,10 @@ class MatchSpec(metaclass=MatchSpecType):
                     builder.append(version)
             elif version[-2:] == ".*":
                 builder.append("=" + version[:-2])
+            # Skip wildcard-only versions, to avoid an empty "=" in the output.
+            # See https://github.com/conda/conda/issues/14357 for more info.
+            elif version == "*":
+                pass
             elif version[-1] == "*":
                 builder.append("=" + version[:-1])
             elif version.startswith("=="):
@@ -387,7 +391,8 @@ class MatchSpec(metaclass=MatchSpecType):
     def conda_build_form(self):
         builder = []
         name = self.get_exact_value("name")
-        assert name
+        if not name:
+            raise ValueError(".conda_build_form() requires a non-empty spec name.")
         builder.append(name)
 
         build = self.get_raw_value("build")
@@ -512,7 +517,8 @@ class MatchSpec(metaclass=MatchSpecType):
         val = self.get_raw_value("fn") or self.get_raw_value("url")
         if val:
             val = basename(val)
-        assert val
+        if not val:
+            raise ValueError(".fn cannot be empty.")
         return val
 
     @classmethod
@@ -711,7 +717,7 @@ def _parse_spec_str(spec_str):
     spec_str = spec_split[0]
 
     # Step 2. done if spec_str is a tarball
-    if is_package_file(spec_str):
+    if context.plugin_manager.has_package_extension(spec_str):
         # treat as a normal url
         if not is_url(spec_str):
             spec_str = unquote(path_to_url(expand(spec_str)))
